******
Mopidy
******

Mopidy is an `Music Player Daemon <http://mpd.wikia.com/>`_ (MPD) server with a
`Spotify <http://www.spotify.com/>`_ backend. Using a standard MPD client you
can search for music in Spotify's vast archive, manage Spotify playlists and
play music from Spotify.

To install Mopidy, check out
`the installation docs <http://www.mopidy.com/docs/installation/>`_.

* `Documentation <http://www.mopidy.com/>`_
* `Source code <http://github.com/jodal/mopidy>`_
* `Issue tracker <http://github.com/jodal/mopidy/issues>`_
* IRC: ``#mopidy`` at `irc.freenode.net <http://freenode.net/>`_
* `Presentation of Mopidy <http://www.slideshare.net/jodal/mopidy-3380516>`_
